@@ -1,4 +1,4 @@
-from typing import Dict, NamedTuple, TypedDict
+from typing import Dict, NamedTuple, Optional, TypedDict
 
 from .config import Config
 
@@ -7,22 +7,26 @@ class Profile(NamedTuple):
     display_name: str
     region: str
     arn: str
+    aws_saml_url: Optional[str] = None
 
 
 class OrgParams(TypedDict, total=False):
-    okta: Dict[str, str]
+    aws_saml_url: str
+    aws_okta_params: Dict[str, str]
+    saml2aws_params: Dict[str, str]
     profiles: Dict[str, Profile]
 
 
 PARAMS: Dict[str, OrgParams] = {
     "launch-darkly": {
-        "okta": {
-            "aws_saml_url": "home/amazon_aws/0oaj4aow7gPk26Fy6356/272",
+        "aws_saml_url": "https://launchdarkly.okta.com/home/amazon_aws/0oaj4aow7gPk26Fy6356/272",
+        "aws_okta_params": {
             "mfa_provider": "OKTA",
             "mfa_factor_type": "push",
             "assume_role_ttl": "1h",
             "session_ttl": "15m",
         },
+        "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "900"},
         "profiles": {
             "prod": Profile(
                 display_name="Prod",
@@ -50,17 +54,45 @@ PARAMS: Dict[str, OrgParams] = {
                 arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
             ),
         },
-    }
+    },
+    "sym": {
+        "aws_okta_params": {},
+        "saml2aws_params": {"mfa": "Auto"},
+        "profiles": {
+            "chris": Profile(
+                display_name="Chris",
+                region="us-east-1",
+                arn="arn:aws:iam::185243338273:role/SSMDemo",
+                aws_saml_url="https://dev-291131.okta.com/home/amazon_aws/0oaizjxdwPw8eoNCm4x6/272",
+            ),
+            "jon": Profile(
+                display_name="Jon",
+                region="us-east-1",
+                arn="arn:aws:iam::838419636750:role/JonSSMDemo",
+                aws_saml_url="https://dev-291131.okta.com/home/amazon_aws/0oakt491rxntIE1bx4x6/272",
+            ),
+        },
+    },
 }
 
 
 def get_org_params() -> OrgParams:
     config = Config()
-    return PARAMS[config["org"]]
+    return PARAMS[config.get_org()]
 
 
-def get_okta_section() -> Dict[str, str]:
-    return get_org_params()["okta"]
+def get_aws_saml_url(resource: str) -> str:
+    org_params = get_org_params()
+    profile = org_params["profiles"][resource]
+    return profile.aws_saml_url or org_params["aws_saml_url"]
+
+
+def get_aws_okta_params() -> Dict[str, str]:
+    return get_org_params()["aws_okta_params"]
+
+
+def get_saml2aws_params() -> Dict[str, str]:
+    return get_org_params()["saml2aws_params"]
 
 
 def get_profiles() -> Dict[str, Profile]:
